==> qt-creator-2.2.0-src.zip: qt-creator-2.2.0-src/src/plugins/analyzerbase/analyzerrunconfigwidget.h <==
/**************************************************************************
**
** This file is part of Qt Creator Instrumentation Tools
**
** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
**
** Author: Milian Wolff, KDAB (milian.wolff@kdab.com)
**
** Contact: Nokia Corporation (info@qt.nokia.com)
**
**
** GNU Lesser General Public License Usage
**
** This file may be used under the terms of the GNU Lesser General Public
** License version 2.1 as published by the Free Software Foundation and
** appearing in the file LICENSE.LGPL included in the packaging of this file.
** Please review the following information to ensure the GNU Lesser General
** Public License version 2.1 requirements will be met:
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights. These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** Other Usage
**
** Alternatively, this file may be used in accordance with the terms and
** conditions contained in a signed written agreement between you and Nokia.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
**
**************************************************************************/


#ifndef ANALYZER_INTERNAL_ANALYZERRUNCONFIGWIDGET_H
#define ANALYZER_INTERNAL_ANALYZERRUNCONFIGWIDGET_H

#include <projectexplorer/runconfiguration.h>

QT_BEGIN_NAMESPACE
class QStandardItemModel;

namespace Ui {
class AnalyzerConfigWidget;
}
QT_END_NAMESPACE

namespace Utils {
class DetailsWidget;
}

namespace Analyzer {

class AnalyzerSettings;

namespace Internal {

class AnalyzerRunConfigWidget : public ProjectExplorer::RunConfigWidget
{
    Q_OBJECT

public:
    AnalyzerRunConfigWidget();

    virtual QString displayName() const;

    void setRunConfiguration(ProjectExplorer::RunConfiguration *rc);

private:
    Utils::DetailsWidget *m_detailsWidget;
};

}
}

#endif // ANALYZER_INTERNAL_ANALYZERRUNCONFIGWIDGET_H

==> qt-creator-2.3.1-src.zip: qt-creator-2.3.1-src/src/plugins/analyzerbase/analyzerrunconfigwidget.h <==
/**************************************************************************
**
** This file is part of Qt Creator Instrumentation Tools
**
** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
**
** Author: Milian Wolff, KDAB (milian.wolff@kdab.com)
**
** Contact: Nokia Corporation (info@qt.nokia.com)
**
**
** GNU Lesser General Public License Usage
**
** This file may be used under the terms of the GNU Lesser General Public
** License version 2.1 as published by the Free Software Foundation and
** appearing in the file LICENSE.LGPL included in the packaging of this file.
** Please review the following information to ensure the GNU Lesser General
** Public License version 2.1 requirements will be met:
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights. These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** Other Usage
**
** Alternatively, this file may be used in accordance with the terms and
** conditions contained in a signed written agreement between you and Nokia.
**
** If you have questions regarding the use of this file, please contact
** Nokia at info@qt.nokia.com.
**
**************************************************************************/

#ifndef ANALYZER_INTERNAL_ANALYZERRUNCONFIGWIDGET_H
#define ANALYZER_INTERNAL_ANALYZERRUNCONFIGWIDGET_H

#include "analyzerbase_global.h"
#include "analyzersettings.h"

#include <projectexplorer/runconfiguration.h>

#include <QtGui/QComboBox>
#include <QtGui/QPushButton>

namespace Utils {
class DetailsWidget;
}

namespace Analyzer {

class AnalyzerSettings;

class ANALYZER_EXPORT AnalyzerRunConfigWidget : public ProjectExplorer::RunConfigWidget
{
    Q_OBJECT

public:
    AnalyzerRunConfigWidget();

    virtual QString displayName() const;

    void setRunConfiguration(ProjectExplorer::RunConfiguration *rc);

private slots:
    void chooseSettings(int setting);
    void restoreGlobal();

private:
    Utils::DetailsWidget *m_detailsWidget;
    QWidget *m_subConfigWidget;
    AnalyzerProjectSettings *m_settings;
    QComboBox *m_settingsCombo;
    QPushButton *m_restoreButton;
};

} // namespace Analyzer

#endif // ANALYZER_INTERNAL_ANALYZERRUNCONFIGWIDGET_H
